@@ -1,4 +1,6 @@
+#[cfg(feature = "ethers-js")]
 pub use bignumber::{BigNumber, BigNumberError};
+#[cfg(feature = "bn-js")]
 pub use bn::{BNError, BN};
 
 mod bignumber;
